package com.ruoyi.system.mapper.projectV2;

import com.ruoyi.system.domain.projectV2.ZsyzProjectDept;

import java.util.List;

/**
 * 招商引资_项目和部门关联Mapper接口
 * 
 * @author boman
 * @date 2023-02-23
 */
public interface ZsyzProjectDeptMapper 
{
    /**
     * 查询招商引资_项目和部门关联
     * 
     * @param id 招商引资_项目和部门关联ID
     * @return 招商引资_项目和部门关联
     */
    public ZsyzProjectDept selectZsyzProjectDeptById(Long id);

    /**
     * 查询招商引资_项目和部门关联列表
     * 
     * @param zsyzProjectDept 招商引资_项目和部门关联
     * @return 招商引资_项目和部门关联集合
     */
    public List<ZsyzProjectDept> selectZsyzProjectDeptList(ZsyzProjectDept zsyzProjectDept);
    public ZsyzProjectDept selectZsyzProjectDeptByXmId(ZsyzProjectDept zsyzProjectDept);

    /**
     * 新增招商引资_项目和部门关联
     * 
     * @param zsyzProjectDept 招商引资_项目和部门关联
     * @return 结果
     */
    public int insertZsyzProjectDept(ZsyzProjectDept zsyzProjectDept);

    /**
     * 修改招商引资_项目和部门关联
     * 
     * @param zsyzProjectDept 招商引资_项目和部门关联
     * @return 结果
     */
    public int updateZsyzProjectDept(ZsyzProjectDept zsyzProjectDept);
    public int updateZsyzProjectDeptByXmId(ZsyzProjectDept zsyzProjectDept);
    public int deleteZsyzProjectDeptByXmId(Long xmId);

    /**
     * 删除招商引资_项目和部门关联
     * 
     * @param id 招商引资_项目和部门关联ID
     * @return 结果
     */
    public int deleteZsyzProjectDeptById(Long id);

    /**
     * 批量删除招商引资_项目和部门关联
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteZsyzProjectDeptByIds(Long[] ids);
}
